@@ -1,7 +1,7 @@
 # -*- coding: utf-8 -*-
-from zvdata import IntervalLevel
-from zvt.api import get_kdata
-from zvt.api.common import to_high_level_kdata, get_recent_report_date
+from zvt.contract import IntervalLevel
+from zvt.api.quote import get_kdata
+from zvt.api.quote import to_high_level_kdata, get_recent_report_date
 from ..context import init_test_context
 
 init_test_context()
