@@ -1,11 +1,10 @@
-from zvdata.contract import get_db_session
-from zvdata import IntervalLevel
+from zvt.api.quote import get_kdata
+from zvt.contract import IntervalLevel
+from zvt.contract.api import get_db_session
 from ..context import init_test_context
 
 init_test_context()
 
-from zvt.api import quote
-
 day_k_session = get_db_session(provider='joinquant',
                                db_name='stock_1d_kdata')  # type: sqlalchemy.orm.Session
 
@@ -14,9 +13,9 @@ day_1h_session = get_db_session(provider='joinquant',
 
 
 def test_jq_603220_kdata():
-    df = quote.get_kdata(entity_id='stock_sh_603220', session=day_k_session, level=IntervalLevel.LEVEL_1DAY,
-                         provider='joinquant')
+    df = get_kdata(entity_id='stock_sh_603220', session=day_k_session, level=IntervalLevel.LEVEL_1DAY,
+                   provider='joinquant')
     print(df)
-    df = quote.get_kdata(entity_id='stock_sh_603220', session=day_1h_session, level=IntervalLevel.LEVEL_1HOUR,
-                         provider='joinquant')
+    df = get_kdata(entity_id='stock_sh_603220', session=day_1h_session, level=IntervalLevel.LEVEL_1HOUR,
+                   provider='joinquant')
     print(df)
