@@ -1,5 +1,6 @@
 from typing import List, Union
 
+import numpy as np
 import pandas as pd
 
 from zvt.api import AdjustType
@@ -62,6 +63,33 @@ class BullFactor(TechnicalFactor):
         self.result_df = s.to_frame(name='score')
 
 
+class KeepBullFactor(BullFactor):
+    def __init__(self, entity_schema: EntityMixin = Stock, provider: str = None, entity_provider: str = None,
+                 entity_ids: List[str] = None, exchanges: List[str] = None, codes: List[str] = None,
+                 the_timestamp: Union[str, pd.Timestamp] = None, start_timestamp: Union[str, pd.Timestamp] = None,
+                 end_timestamp: Union[str, pd.Timestamp] = None,
+                 columns: List = ['id', 'entity_id', 'timestamp', 'level', 'open', 'close', 'high', 'low'],
+                 filters: List = None, order: object = None, limit: int = None,
+                 level: Union[str, IntervalLevel] = IntervalLevel.LEVEL_1DAY, category_field: str = 'entity_id',
+                 time_field: str = 'timestamp', computing_window: int = None, keep_all_timestamp: bool = False,
+                 fill_method: str = 'ffill', effective_number: int = None, transformer: Transformer = MacdTransformer(),
+                 accumulator: Accumulator = None, need_persist: bool = False, dry_run: bool = False,
+                 adjust_type: Union[AdjustType, str] = None, keep_window=20) -> None:
+        self.keep_window = keep_window
+        super().__init__(entity_schema, provider, entity_provider, entity_ids, exchanges, codes, the_timestamp,
+                         start_timestamp, end_timestamp, columns, filters, order, limit, level, category_field,
+                         time_field, computing_window, keep_all_timestamp, fill_method, effective_number, transformer,
+                         accumulator, need_persist, dry_run, adjust_type)
+
+    def do_compute(self):
+        super().do_compute()
+        df = self.result_df['score'].groupby(level=0).rolling(window=self.keep_window,
+                                                              min_periods=self.keep_window).apply(
+            lambda x: np.logical_and.reduce(x))
+        df = df.reset_index(level=0, drop=True)
+        self.result_df['score'] = df
+
+
 if __name__ == '__main__':
     factor = TechnicalFactor(codes=['000338'],
                              start_timestamp='2019-01-01',
