@@ -14,17 +14,6 @@ ZVT_TEST_DATA_PATH = os.path.join(ZVT_TEST_HOME, 'data')
 
 DATA_SAMPLE_ZIP_PATH = os.path.abspath(os.path.join(os.path.dirname(__file__), 'samples', 'data.zip'))
 
-# ****** setting for crypto currency ****** #
-COIN_EXCHANGES = ["binance", "huobipro"]
-
-# COIN_BASE = ["BTC", "ETH", "XRP", "BCH", "EOS", "LTC", "XLM", "ADA", "IOTA", "TRX", "NEO", "DASH", "XMR",
-#                        "BNB", "ETC", "QTUM", "ONT"]
-
-COIN_BASE = ["BTC", "ETH", "EOS"]
-
-COIN_PAIRS = [("{}/{}".format(item, "USDT")) for item in COIN_BASE] + \
-             [("{}/{}".format(item, "USD")) for item in COIN_BASE]
-
 # ****** setting for stocks ****** #
 # 覆盖维度 银行/保险/企业/券商 创业板 中小板 主板
 SAMPLE_STOCK_CODES = ['000001', '000783', '000778', '603220', '601318', '000338', '002572', '300027']
